==> jc-1.4.0.tar.gz: java/awt/JobAttributes__24SidesType.h <==
// public final class java.awt.JobAttributes$SidesType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 7afda46a1df14fa3 java_awt_JobAttributes__24SidesType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24SidesType_H_
#define _JC_java_awt_JobAttributes__24SidesType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24SidesType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24SidesType$sub_refs	_jc_java_awt_JobAttributes__24SidesType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$sub_nonrefs	_jc_java_awt_JobAttributes__24SidesType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$refs	_jc_java_awt_JobAttributes__24SidesType$refs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$nonrefs	_jc_java_awt_JobAttributes__24SidesType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$object	_jc_java_awt_JobAttributes__24SidesType$object;

typedef struct _jc_java_awt_JobAttributes__24SidesType$fields_struct	_jc_java_awt_JobAttributes__24SidesType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24SidesType$vmethods	_jc_java_awt_JobAttributes__24SidesType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24SidesType$vtable	_jc_java_awt_JobAttributes__24SidesType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24SidesType$vtype	_jc_java_awt_JobAttributes__24SidesType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24SidesType$fields_struct {
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24SidesType$object	*ONE__5fSIDED;
	struct _jc_java_awt_JobAttributes__24SidesType$object	*TWO__5fSIDED__5fLONG__5fEDGE;
	struct _jc_java_awt_JobAttributes__24SidesType$object	*TWO__5fSIDED__5fSHORT__5fEDGE;
};
extern _jc_java_awt_JobAttributes__24SidesType$fields_struct _jc_java_awt_JobAttributes__24SidesType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24SidesType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24SidesType$object *, jint);

// Static methods
extern void _jc_java_awt_JobAttributes__24SidesType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24SidesType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24SidesType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24SidesType$vmethods	java_awt_JobAttributes__24SidesType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24SidesType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24SidesType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24SidesType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24SidesType$refs {
    _jc_java_awt_JobAttributes__24SidesType$sub_refs	java_awt_JobAttributes__24SidesType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24SidesType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24SidesType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24SidesType$sub_nonrefs	java_awt_JobAttributes__24SidesType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24SidesType$object {
	_jc_java_awt_JobAttributes__24SidesType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24SidesType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24SidesType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24SidesType$vtype _jc_java_awt_JobAttributes__24SidesType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24SidesType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24SidesType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24SidesType_H_ */

==> jc-1.4.6.tar.gz: java/awt/JobAttributes__24SidesType.h <==
// public final class java.awt.JobAttributes$SidesType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 7afda46a1df14fa3 java_awt_JobAttributes__24SidesType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24SidesType_H_
#define _JC_java_awt_JobAttributes__24SidesType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24SidesType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24SidesType$sub_refs	_jc_java_awt_JobAttributes__24SidesType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$sub_nonrefs	_jc_java_awt_JobAttributes__24SidesType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$refs	_jc_java_awt_JobAttributes__24SidesType$refs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$nonrefs	_jc_java_awt_JobAttributes__24SidesType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24SidesType$object	_jc_java_awt_JobAttributes__24SidesType$object;

typedef struct _jc_java_awt_JobAttributes__24SidesType$fields_struct	_jc_java_awt_JobAttributes__24SidesType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24SidesType$vmethods	_jc_java_awt_JobAttributes__24SidesType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24SidesType$vtable	_jc_java_awt_JobAttributes__24SidesType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24SidesType$vtype	_jc_java_awt_JobAttributes__24SidesType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24SidesType$fields_struct {
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24SidesType$object	*ONE__5fSIDED;
	struct _jc_java_awt_JobAttributes__24SidesType$object	*TWO__5fSIDED__5fLONG__5fEDGE;
	struct _jc_java_awt_JobAttributes__24SidesType$object	*TWO__5fSIDED__5fSHORT__5fEDGE;
};
extern _jc_java_awt_JobAttributes__24SidesType$fields_struct _jc_java_awt_JobAttributes__24SidesType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24SidesType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24SidesType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_JobAttributes__24SidesType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24SidesType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24SidesType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24SidesType$vmethods	java_awt_JobAttributes__24SidesType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24SidesType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24SidesType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24SidesType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24SidesType$refs {
    _jc_java_awt_JobAttributes__24SidesType$sub_refs	java_awt_JobAttributes__24SidesType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24SidesType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24SidesType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24SidesType$sub_nonrefs	java_awt_JobAttributes__24SidesType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24SidesType$object {
	_jc_java_awt_JobAttributes__24SidesType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24SidesType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24SidesType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24SidesType$vtype _jc_java_awt_JobAttributes__24SidesType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24SidesType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24SidesType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24SidesType_H_ */
